<?php

////////////////////////////////////////////////////////////////////
// Settig Theme-options
////////////////////////////////////////////////////////////////////
include_once( trailingslashit( get_template_directory() ) . '/lib/plugin-activation.php' );  
include_once( trailingslashit( get_template_directory() ) . '/lib/theme-config.php' );
include_once( trailingslashit( get_template_directory() ) . '/lib/metaboxes.php' );

add_action( 'after_setup_theme', 'kakina_setup' );

if( !function_exists( 'kakina_setup' ) ) :
function kakina_setup() {

  // Theme lang
  load_theme_textdomain( 'kakina', get_template_directory() . '/languages' );

  // Add Title Tag Support
  add_theme_support( 'title-tag' );
  
  // Register Menus
  register_nav_menus(
      array(
          'main_menu' => __( 'Main Menu', 'kakina' ),
      )
  );
  
  // Add support for a featured image and the size
  add_theme_support( 'post-thumbnails' );
  set_post_thumbnail_size( 300,300, true );
  add_image_size( 'kakina-single', 688, 325, true );
  add_image_size( 'kakina-slider', 855, 450, true );

  // Adds RSS feed links to for posts and comments.
  add_theme_support( 'automatic-feed-links' );
  
  add_theme_support( 'woocommerce' );
    
}
endif;

////////////////////////////////////////////////////////////////////
// Display a admin notices
////////////////////////////////////////////////////////////////////
  add_action( 'admin_notices', 'kakina_admin_notice' );
    function kakina_admin_notice() {
        global $current_user;
            $user_id = $current_user->ID;
            /* Check that the user hasn't already clicked to ignore the message */
        if ( ! get_user_meta( $user_id, 'kakina_ignore_notice' ) ) {
            echo '<div class="updated notice-info point-notice" style="position:relative;"><p>'; 
            printf( __( 'Like Kakina theme? You will <strong>LOVE Kakina PRO</strong>! ', 'kakina' ) . '<a href="' . esc_url( 'http://themes4wp.com/product/kakina-pro/' ) . '" target="_blank">' . __( 'Click here for all the exciting features.', 'kakina' ) . '</a><a href="%1$s" class="dashicons dashicons-dismiss dashicons-dismiss-icon" style="position: absolute; top: 8px; right: 8px; color: #222; opacity: 0.4; text-decoration: none !important;"></a>', '?kakina_notice_ignore=0' );
            echo "</p></div>";
        }
  }

  add_action( 'admin_init', 'kakina_notice_ignore' );
    function kakina_notice_ignore() {
        global $current_user;
            $user_id = $current_user->ID;
            /* If user clicks to ignore the notice, add that to their user meta */
            if ( isset( $_GET['kakina_notice_ignore']) && '0' == $_GET['kakina_notice_ignore'] ) {
                add_user_meta( $user_id, 'kakina_ignore_notice', 'true', true );
        }
  }

  add_action( 'customize_controls_print_footer_scripts', 'kakina_pro_banner' );
    function kakina_pro_banner() {
        echo '<a href="' . esc_url( 'http://themes4wp.com/product/kakina-pro/' ).'" id="pro-banner" style="display: none; margin-top: 10px; background: #192429;" target="_blank"><img src="' . get_template_directory_uri() . '/img/kakina-pro.jpg" /></a>';
        echo '<script type="text/javascript">jQuery(document).ready(function($) { $("#pro-banner").appendTo("#customize-info").css("display", "block"); });</script>';
  }

////////////////////////////////////////////////////////////////////
// Enqueue Styles (normal style.css and bootstrap.css)
////////////////////////////////////////////////////////////////////
    function kakina_theme_stylesheets()
    {
        wp_enqueue_style( 'kakina-bootstrap-css', get_template_directory_uri() . '/css/bootstrap.css', array(), '1', 'all' );
        wp_enqueue_style( 'kakina-stylesheet', get_stylesheet_uri(), array(), '1', 'all' );
        // load Font Awesome css
	      wp_enqueue_style( 'kakina-font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', false );
	      wp_enqueue_style( 'kakina-flexslider-css', get_template_directory_uri() . '/css/flexslider.css', false );
    }
    add_action( 'wp_enqueue_scripts', 'kakina_theme_stylesheets' );

////////////////////////////////////////////////////////////////////
// Register Bootstrap JS with jquery
////////////////////////////////////////////////////////////////////
    function kakina_theme_js()
    { 
        wp_enqueue_script( 'kakina-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array( 'jquery' ), true );
        wp_enqueue_script( 'kakina-theme-js', get_template_directory_uri() . '/js/customscript.js', array( 'jquery' ), true );
        wp_enqueue_script( 'kakina-flexslider', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array( 'jquery' ), true );
    }
    add_action( 'wp_enqueue_scripts', 'kakina_theme_js' );

////////////////////////////////////////////////////////////////////
// Register Custom Navigation Walker include custom menu widget to use walkerclass
////////////////////////////////////////////////////////////////////

    require_once( 'lib/wp_bootstrap_navwalker.php' );
    
////////////////////////////////////////////////////////////////////
// Theme Info page
////////////////////////////////////////////////////////////////////

    if ( is_admin() ) {
    	require_once( trailingslashit( get_template_directory() ) . '/lib/theme-info.php' );
    }    
        
////////////////////////////////////////////////////////////////////
// Register Widgets
////////////////////////////////////////////////////////////////////
        
add_action( 'widgets_init', 'kakina_widgets_init' );

function kakina_widgets_init() {
        
        register_sidebar(
            array(
            'name' => __( 'Homepage Sidebar', 'kakina' ),
            'id' => 'kakina-home-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));
        
        register_sidebar(
            array(
            'name' => __( 'Right Sidebar', 'kakina' ),
            'id' => 'kakina-right-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));

        register_sidebar(
            array(
            'name' => __( 'Left Sidebar', 'kakina' ),
            'id' => 'kakina-left-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));
        register_sidebar( 
            array(
            'name'            => __( 'Footer Section', 'kakina' ),
            'id'              => 'kakina-footer-area',
            'description'     => __( 'Content Footer Section', 'kakina' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s col-md-3">',
            'after_widget' => '</div>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));
              
}
////////////////////////////////////////////////////////////////////
// Register hook and action to set Main content area col-md- width based on sidebar declarations
////////////////////////////////////////////////////////////////////

add_action( 'kakina_main_content_width_hook', 'kakina_main_content_width_columns' );

function kakina_main_content_width_columns () {

    $columns = '12';

    if (get_theme_mod( 'rigth-sidebar-check', 1 ) != 0 ) {
        $columns = $columns - absint( get_theme_mod( 'right-sidebar-size', 3 ) );
    }

    if (get_theme_mod( 'left-sidebar-check', 0 ) != 0 ) {
        $columns = $columns - absint( get_theme_mod( 'left-sidebar-size', 3 ) );
    }

    echo $columns;
}

function kakina_main_content_width() {
    do_action( 'kakina_main_content_width_hook' );
}

////////////////////////////////////////////////////////////////////
// Set Content Width
////////////////////////////////////////////////////////////////////

if ( ! isset( $content_width ) ) $content_width = 800;

////////////////////////////////////////////////////////////////////
// Breadcrumbs
////////////////////////////////////////////////////////////////////
function kakina_breadcrumb() {
	global $post, $wp_query;
	// schema link
	$home = __( 'Home', 'kakina' );
	$delimiter = ' &raquo; ';
	$homeLink = home_url();
	if (is_home() || is_front_page()) {
		// no need for breadcrumbs in homepage
	}
	else {
		echo '<div id="breadcrumbs" >';
		echo '<div class="breadcrumbs-inner text-right">';
		// main breadcrumbs lead to homepage
		echo '<span><a href="' . esc_url($homeLink) . '">' . '<i class="fa fa-home"></i><span>' . esc_attr($home) . '</span>' . '</a></span>' . $delimiter . ' ';
		// if blog page exists
		if ( get_page_by_path('blog') ) {
			if ( ! is_page('blog') ) {
				echo '<span><a href="' . esc_url( get_permalink( get_page_by_path('blog') ) ) . '">' . '<span>' . _x( 'Blog', 'Breadcrumbs', 'kakina' ).'</span></a></span>' . $delimiter . ' ';
			}
		}
		if (is_category()) {
			$thisCat = get_category(get_query_var('cat') , false);
			if ($thisCat->parent != 0) {
				$category_link = get_category_link($thisCat->parent);
				echo '<span><a href="' . esc_url($category_link) . '">' . '<span>' . esc_attr(get_cat_name($thisCat->parent)) . '</span>' . '</a></span>' . $delimiter . ' ';
			}
			$category_id = get_cat_ID(single_cat_title('', false));
			$category_link = get_category_link($category_id);
			echo '<span><a href="' . esc_url($category_link) . '">' . '<span>' . esc_attr(single_cat_title('', false)) . '</span>' . '</a></span>';
		}
		elseif (is_single() && !is_attachment()) {
			if (get_post_type() != 'post') {
				$post_type = get_post_type_object(get_post_type());
				$slug = $post_type->rewrite;
				echo '<span><a href="' . esc_url($homeLink) . '/' . $slug['slug'] . '">' . '<span>' . esc_attr($post_type->labels->singular_name) . '</span>' . '</a></span>';
				echo ' ' . $delimiter . ' ' . get_the_title();
			}
			else {
				$category = get_the_category();
				if ($category) {
					foreach($category as $cat) {
						echo '<span><a href="' . esc_url(get_category_link($cat->term_id)) . '">' . '<span>' . esc_attr($cat->name) . '</span>' . '</a></span>' . $delimiter . ' ';
					}
				}
				echo get_the_title();
			}
		}
		elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404() && !is_search()) {
			$post_type = get_post_type_object(get_post_type());
			echo $post_type->labels->singular_name;
		}
		elseif (is_attachment()) {
			$parent = get_post($post->post_parent);
			echo '<span><a href="' . esc_url(get_permalink($parent)) . '">' . '<span>' . esc_attr($parent->post_title) . '</span>' . '</a></span>';
			echo ' ' . $delimiter . ' ' . get_the_title();
		}
		elseif (is_page() && !$post->post_parent) {
			$get_post_slug = $post->post_name;
			$post_slug = str_replace('-', ' ', $get_post_slug);
			echo '<span><a href="' . esc_url(get_permalink()) . '">' . '<span>' . esc_attr(ucfirst($post_slug)) . '</span>' . '</a></span>';
		}
		elseif (is_page() && $post->post_parent) {
			$parent_id = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) {
				$page = get_page($parent_id);
				$breadcrumbs[] = '<span><a href="' . esc_url(get_permalink($page->ID)) . '">' . '<span>' . esc_attr(get_the_title($page->ID)) . '</span>' . '</a></span>';
				$parent_id = $page->post_parent;
			}
			$breadcrumbs = array_reverse($breadcrumbs);
			for ($i = 0; $i < count($breadcrumbs); $i++) {
				echo $breadcrumbs[$i];
				if ($i != count($breadcrumbs) - 1) echo ' ' . $delimiter . ' ';
			}
			echo $delimiter . '<span><a href="' . esc_url(get_permalink()) . '">' . '<span>' . esc_attr(the_title_attribute('echo=0')) . '</span>' . '</a></span>';
		}
		elseif (is_tag()) {
			$tag_id = get_term_by('name', single_cat_title('', false) , 'post_tag');
			if ($tag_id) {
				$tag_link = get_tag_link($tag_id->term_id);
			}
			echo '<span><a href="' . esc_url($tag_link) . '">' . '<span>' . esc_attr(single_cat_title('', false)) . '</span>' . '</a></span>';
		}
		elseif (is_author()) {
			global $author;
			$userdata = get_userdata($author);
			echo '<span><a href="' . esc_url(get_author_posts_url($userdata->ID)) . '">' . '<span>' . esc_attr($userdata->display_name) . '</span>' . '</a></span>';
		}
		elseif (is_404()) {
			echo __( 'Error 404', 'kakina' );
		}
		elseif (is_search()) {
			echo __( 'Search results for ' , 'kakina' ) . ' '  . get_search_query();
		}
		elseif (is_day()) {
			echo '<span><a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . '<span>' . esc_attr(get_the_time('Y')) . '</span>' . '</a></span>' . $delimiter . ' ';
			echo '<span><a href="' . esc_url(get_month_link(get_the_time('Y')) , get_the_time('m')) . '">' . '<span>' . esc_attr(get_the_time('F')) . '</span>' . '</a></span>' . $delimiter . ' ';
			echo '<span><a href="' . esc_url(get_day_link(get_the_time('Y')) , get_the_time('m') , get_the_time('d')) . '">' . '<span>' . esc_attr(get_the_time('d')) . '</span>' . '</a></span>';
		}
		elseif (is_month()) {
			echo '<span><a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . '<span>' . esc_attr(get_the_time('Y')) . '</span>' . '</a></span>' . $delimiter . ' ';
			echo '<span><a href="' . esc_url(get_month_link(get_the_time('Y') , get_the_time('m'))) . '">' . '<span>' . esc_attr(get_the_time('F')) . '</span>' . '</a></span>';
		}
		elseif (is_year()) {
			echo '<span><a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . '<span>' . esc_attr(get_the_time('Y')) . '</span>' . '</a></span>';
		}
		if (get_query_var( 'paged' )) {
			if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) echo ' (';
			echo __( 'Page', 'kakina' ) . ' ' . get_query_var( 'paged' );
			if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) echo ')';
		}
		echo '</div></div>';
	}
}

////////////////////////////////////////////////////////////////////
// Display navigation to next/previous pages when applicable
////////////////////////////////////////////////////////////////////
if ( ! function_exists( 'kakina_content_nav' ) ) :
function kakina_content_nav( $nav_id ) {
	global $wp_query, $post;

	// Don't print empty markup on single pages if there's nowhere to navigate.
	if ( is_single() ) {
		$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
		$next = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous )
			return;
	}

	// Don't print empty markup in archives if there's only one page.
	if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) )
		return;

	$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

	?>
	<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo $nav_class; ?>">
		<div class="screen-reader-text"><?php _e( 'Post navigation', 'kakina' ); ?></div>
		<div class="pager">

		<?php if ( is_single() ) : // navigation links for single posts ?>

			<div class="post-navigation row">
        	<div class="post-previous col-md-6"><?php previous_post_link( '%link', '<span class="meta-nav">'. __( 'Previous:', 'kakina' ).'</span> %title' ); ?></div>
        	<div class="post-next col-md-6"><?php next_post_link( '%link', '<span class="meta-nav">'. __( 'Next:', 'kakina' ).'</span> %title' ); ?></div>
      </div>

		<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

			<?php if ( get_next_posts_link() ) : ?>
			<li class="nav-previous previous btn btn-default"><?php next_posts_link( __( 'Older posts', 'kakina' ) ); ?></li>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<li class="nav-next next btn btn-default"><?php previous_posts_link( __( 'Newer posts', 'kakina' ) ); ?></li>
			<?php endif; ?>

		<?php endif; ?>

		</div>
	</nav>
	<?php
}
endif; // content_nav

////////////////////////////////////////////////////////////////////
// Social links
////////////////////////////////////////////////////////////////////
if ( ! function_exists( 'kakina_social_links' ) ) :
/**
 * This function is for social links display on header
 *
 * Get links through Theme Options
 */
function kakina_social_links() {
   $twp_social_links = array( 'twp_social_facebook' 	=> __( 'Facebook', 'kakina' ),
									'twp_social_twitter' 		=> __( 'Twitter', 'kakina' ),
									'twp_social_google' 	=> __( 'Google-Plus' , 'kakina' ),
									'twp_social_instagram' 	=> __( 'Instagram', 'kakina' ),
									'twp_social_pin' 	=> __( 'Pinterest', 'kakina' ),
									'twp_social_youtube' 		=> __( 'YouTube', 'kakina' ),
									'twp_social_reddit' 	=> __( 'Reddit', 'kakina' ),
							 	);
	?>
	<div class="social-links">
		<ul>
		<?php
			$i=0;
			$twp_links_output = '';
			foreach( $twp_social_links as $key => $value ) {
				$link = get_theme_mod( $key , '' );
				if ( !empty( $link ) ) {
					
					$twp_links_output .=
						'<li><a href="' . esc_url( $link ) . '" target="_blank"><i class="fa fa-' . strtolower( $value ) . '"></i></a></li>';
				}
				$i++;
			}
			echo $twp_links_output;
		?>
		</ul>
	</div><!-- .social-links -->
	<?php
}
endif;

////////////////////////////////////////////////////////////////////
// Pagination
////////////////////////////////////////////////////////////////////
if ( ! function_exists( 'kakina_pagination' ) ) :
  function kakina_pagination() {
      global $wp_query;
      $big = 999999999;
      $pages = paginate_links(array(
          'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
          'format' => '?page=%#%',
          'current' => max(1, get_query_var('paged')),
          'total' => $wp_query->max_num_pages,
          'prev_next' => false,
          'type' => 'array',
          'prev_next' => TRUE,
          'prev_text' => __( '&larr; Previous', 'kakina' ),
          'next_text' => __( 'Next &rarr;', 'kakina' ),
              ));
      if ( is_array( $pages ) ) {
          $current_page = ( get_query_var( 'paged' ) == 0 ) ? 1 : get_query_var( 'paged' );
          echo '<div class="footer-pagination"><ul class="pagination">';
          foreach ( $pages as $i => $page ) {
              if ( $current_page == 1 && $i == 0 ) {
                  echo "<li class='active'>$page</li>";
              } else {
                  if ( $current_page != 1 && $current_page == $i ) {
                      echo "<li class='active'>$page</li>";
                  } else {
                      echo "<li>$page</li>";
                  }
              }
          }
          echo '</ul></div>';
      }
  }
endif;
////////////////////////////////////////////////////////////////////
// WooCommerce section
////////////////////////////////////////////////////////////////////
if ( class_exists( 'WooCommerce' ) ) {

////////////////////////////////////////////////////////////////////
// WooCommerce header cart
////////////////////////////////////////////////////////////////////
  if ( ! function_exists( 'kakina_cart_link' ) ) {
  	function kakina_cart_link() {
  		?>	
  			<a class="cart-contents text-right" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php _e( 'View your shopping cart', 'kakina' ); ?>">
  				<i class="fa fa-shopping-cart"><span class="count"><?php echo WC()->cart->get_cart_contents_count();?></span></i><div class="amount-title hidden-xs"><?php echo _e( 'Cart ', 'kakina' ); ?></div><div class="amount-cart hidden-xs"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></div> 
  			</a>
  		<?php
  	}
  }
  if ( ! function_exists( 'kakina_head_wishlist' ) ) {
  	function kakina_head_wishlist() {
  		if ( function_exists( 'YITH_WCWL' ) ) { 
            $wishlist_url = YITH_WCWL()->get_wishlist_url();
            ?>
            <div class="top-wishlist text-right">
              <a href="<?php echo esc_url( $wishlist_url ); ?>" title="Wishlist" data-toggle="tooltip">
                <div class="fa fa-heart"><div class="count"><span><?php echo yith_wcwl_count_products(); ?></span></div></div>
              </a>
            </div>
            <?php
            }
  	}
  }
  add_action( 'wp_ajax_yith_wcwl_update_single_product_list', 'kakina_head_wishlist' );
  add_action( 'wp_ajax_nopriv_yith_wcwl_update_single_product_list', 'kakina_head_wishlist' );
  
  if ( ! function_exists( 'kakina_header_cart' ) ) {
  	function kakina_header_cart() {
  		?>
  		<div class="header-cart text-right col-md-3 col-sm-6 col-md-push-6">
  		  <div class="header-cart-inner">
          <?php kakina_cart_link(); ?>
          <ul class="site-header-cart menu list-unstyled">
        		<li>
        			<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
        		</li>
      		</ul>
        </div>
        <?php if ( get_theme_mod( 'wishlist-top-icon', 0 ) != 0)  { echo kakina_head_wishlist(); }?>
  		</div>
  		<?php
  	}
  }
  if ( ! function_exists( 'kakina_header_add_to_cart_fragment' ) ) {
    add_filter( 'woocommerce_add_to_cart_fragments', 'kakina_header_add_to_cart_fragment' );
    function kakina_header_add_to_cart_fragment( $fragments ) {
    	ob_start();
    	
      kakina_cart_link();
    	
    	$fragments['a.cart-contents'] = ob_get_clean();
    	
    	return $fragments;
    }
  }
////////////////////////////////////////////////////////////////////
// Change number of products displayed per page
////////////////////////////////////////////////////////////////////  
  add_filter( 'loop_shop_per_page', create_function( '$cols', 'return ' . get_theme_mod( 'archive_number_products', 24 ) . ';' ), 20 );
  
////////////////////////////////////////////////////////////////////
// Change number of products per row
////////////////////////////////////////////////////////////////////
  add_filter( 'loop_shop_columns', 'kakina_loop_columns' );
  if (!function_exists('kakina_loop_columns')) {
  	function kakina_loop_columns() {
  		return absint( get_theme_mod( 'archive_number_columns', 4 ) ); 
  	}
  }

////////////////////////////////////////////////////////////////////
// Archive product wishlist button
////////////////////////////////////////////////////////////////////  
  function kakina_wishlist_products() {
      if (function_exists( 'YITH_WCWL' )) { 
      global $product;
      $url = add_query_arg( 'add_to_wishlist', $product->id );
      $id = $product->id;
      $wishlist_url = YITH_WCWL()->get_wishlist_url();
           ?>  
  		<div class="add-to-wishlist-custom add-to-wishlist-<?php echo esc_attr( $id ); ?>">
        <div class="yith-wcwl-add-button show" style="display:block"> <a href="<?php echo esc_url( $url ); ?>" data-toggle="tooltip" data-placement="top" rel="nofollow" data-product-id="<?php echo esc_attr( $id ); ?>" data-product-type="simple" title="<?php _e( 'Add to Wishlist', 'kakina' ); ?>" class="add_to_wishlist"></a><img src="<?php echo get_template_directory_uri() . '/img/loading.gif'; ?>" class="ajax-loading" alt="loading" width="16" height="16"></div>
        <div class="yith-wcwl-wishlistaddedbrowse hide" style="display:none;"> <span class="feedback"><?php _e( 'Added!', 'kakina' ); ?></span> <a href="<?php echo esc_url( $wishlist_url ); ?>"><?php _e( 'View Wishlist', 'kakina' ); ?></a></div>
        <div class="yith-wcwl-wishlistexistsbrowse hide" style="display:none"> <span class="feedback"><?php _e( 'The product is already in the wishlist!', 'kakina' ); ?></span> <a href="<?php echo esc_url( $wishlist_url ); ?>"><?php _e( 'Browse Wishlist', 'kakina' ); ?></a></div>
        <div class="clear"></div>
        <div class="yith-wcwl-wishlistaddresponse"></div>
      </div>
  		<?php
  		}
  }
  add_action( 'woocommerce_after_shop_loop_item', 'kakina_wishlist_products', 20 );
  
 
////////////////////////////////////////////////////////////////////
// Advanced search functionality
////////////////////////////////////////////////////////////////////
  function kakina_advanced_search_query( $query ) {
  
      if( $query->is_search() ) {
          // category terms search.
          if ( isset( $_GET['category'] ) && ! empty( $_GET['category'] ) ) {
              $query->set( 'tax_query', array( array(
                  'taxonomy' => 'product_cat',
                  'field' => 'slug',
                  'terms' => array( $_GET['category'] ) )
              ));
          }    
          return $query;
      }
  }
  add_action( 'pre_get_posts', 'kakina_advanced_search_query', 1000 );
  
}
////////////////////////////////////////////////////////////////////
// WooCommerce end
////////////////////////////////////////////////////////////////////
